==> libreoffice_7.0.4.orig.tar.xz: libreoffice-7.0.4.2/vcl/inc/osx/printview.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#ifndef INCLUDED_VCL_INC_OSX_PRINTVIEW_H
#define INCLUDED_VCL_INC_OSX_PRINTVIEW_H

#include <premac.h>
#include <Cocoa/Cocoa.h>
#include <postmac.h>

#include <vcl/print.hxx>

class AquaSalInfoPrinter;

struct PrintAccessoryViewState
{
    bool        bNeedRestart;
    sal_Int32   nLastPage;

    PrintAccessoryViewState()
    : bNeedRestart( false ), nLastPage( 0 ) {}
};

@interface AquaPrintView : NSView
{
    vcl::PrinterController*     mpController;
    AquaSalInfoPrinter*         mpInfoPrinter;
}
-(id)initWithController: (vcl::PrinterController*)pController
        withInfoPrinter: (AquaSalInfoPrinter*)pInfoPrinter;
-(BOOL)knowsPageRange: (NSRangePointer)range;
-(NSRect)rectForPage: (int)page;
-(NSPoint)locationOfPrintRect: (NSRect)aRect;
-(void)drawRect: (NSRect)rect;
@end

@interface AquaPrintAccessoryView : NSObject
{
}
+(NSObject*)setupPrinterPanel: (NSPrintOperation*)pOp
               withController: (vcl::PrinterController*)pController
                    withState: (PrintAccessoryViewState*)pState;
@end

#endif // INCLUDED_VCL_INC_OSX_PRINTVIEW_H

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_25.8.3.orig.tar.xz: libreoffice-25.8.3.2/vcl/inc/osx/printview.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#pragma once

#include <premac.h>
#include <Cocoa/Cocoa.h>
#include <postmac.h>

#include <vcl/print.hxx>

class AquaSalInfoPrinter;

struct PrintAccessoryViewState
{
    bool        bNeedRestart;
    sal_Int32   nLastPage;

    PrintAccessoryViewState()
    : bNeedRestart( false ), nLastPage( 0 ) {}
};

@interface AquaPrintView : NSView
{
    vcl::PrinterController*     mpController;
    AquaSalInfoPrinter*         mpInfoPrinter;
}
-(id)initWithController: (vcl::PrinterController*)pController
        withInfoPrinter: (AquaSalInfoPrinter*)pInfoPrinter;
-(BOOL)knowsPageRange: (NSRangePointer)range;
-(NSRect)rectForPage: (int)page;
-(NSPoint)locationOfPrintRect: (NSRect)aRect;
-(void)drawRect: (NSRect)rect;
@end

@interface AquaPrintAccessoryView : NSObject
{
}
+(NSObject*)setupPrinterPanel: (NSPrintOperation*)pOp
               withController: (vcl::PrinterController*)pController
                    withState: (PrintAccessoryViewState*)pState;
@end

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
